Parameters — miml documentation

Skip to main content
`Ctrl`+`K`

# Parameters

class miml.transformation.mimlTOml.arithmetic.ArithmeticTransformation

  Bases: `MIMLtoMLTransformation`

  Class that performs an arithmetic transformation to convert a MIMLDataset class to numpy ndarray.

  transform_bag(bag: Bag)

    Transform a bag to a multilabel instance

    # Parameters

    bagBag

      Bag to be transformed

    # Returns

  transform_dataset(dataset: MIMLDataset) → MIMLDataset

    Transform the dataset to multilabel dataset converting each bag into a single instance being the value of each attribute the mean value of the instances in the bag.

    Parameters

    # Returns

    transformed_datasetMIMLDataset

      Transformed dataset